@@ -35,9 +35,9 @@ from .orm import (
     get_query_entities,
     get_tables,
     getdotattr,
-    has_any_changes,
     has_changes,
     identity,
+    is_loaded,
     naturally_equivalent,
     quote,
     table_name,
@@ -62,9 +62,9 @@ __all__ = (
     'get_tables',
     'getdotattr',
     'group_foreign_keys',
-    'has_any_changes',
     'has_changes',
     'identity',
+    'is_loaded',
     'is_auto_assigned_date_column',
     'is_indexed_foreign_key',
     'make_order_by_deterministic',
