@@ -9,14 +9,14 @@ try:
 except:
     pass
 from sqlalchemy import types
-from sqlalchemy_utils import ImproperlyConfigured
+from sqlalchemy_utils.exceptions import ImproperlyConfigured
 from .scalar_coercible import ScalarCoercible
 
 
 class ArrowType(types.TypeDecorator, ScalarCoercible):
     """
     ArrowType provides way of saving Arrow_ objects into database. It
-    automatically changes Arrow_ objects to datatime objects on the way in and
+    automatically changes Arrow_ objects to datetime objects on the way in and
     datetime objects back to Arrow_ objects on the way out (when querying
     database). ArrowType needs Arrow_ library installed.
 
